MXBottomNavBarItemBadgeConfig class

Constructors

MXBottomNavBarItemBadgeConfig({required bool show, double? offsetX, double? offsetY, dynamic mxBadge})

Properties

hashCode int
The hash code for this object.
no setterinherited
mxBadge MXBadge?
getter/setter pair
offsetX double?
final
offsetY double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
show bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited