UseMXCalendarByPopup class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
toRender(
{required BuildContext context, required MXCalendarController controller, String title = '选择日期', VoidCallback? onClose, VoidCallback? onConfirm, bool modelClose = false, MXButton? customConfirmButton}) → dynamic